@@ -3,7 +3,7 @@ function (sp, data, varname, sp.key="id", data.key="id", diverg=FALSE, nbcuts=6,
   tmp <- data[,c(data.key, varname)]
   require(sp)
   require(RColorBrewer)
-  sp@data <- merge(sp@data, tmp, by.x=sp.key, by.y=data.key, all.x=TRUE, all.y=FALSE)
+  sp@data <- merge(sp@data, tmp, by.x=sp.key, by.y=data.key, all.x=TRUE, all.y=FALSE, sort=FALSE)
   tmp.var <- na.omit(sp@data[,varname])
   if (is.null(at)) at <- pretty(tmp.var,n=nbcuts)
   if (!is.null(at) && at.lim) {
